from .http._http_code import HTTPCode
from .http._http_default import DefaultHTTPHeader
from .http._http_header import T_HTTPHeader
from .http._http_header import T_Element
from .http._http_ver import HTTPVersion
from .http.exceptions import *
from .http.payload import Payload
from .http.request import HTTPRequest
from .http.response import HTTPResponse
from .http.typings import *


from setuptools import setup

setup(
    name='py-protocol',
    version='0.0.3a3',
    description= 'Support for network protocol senders',
    long_description='',
    author='Phuc Bao',
    packages=['protocol'],
)